"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListEvents = void 0;
const ListEventsCommand_1 = require("../commands/ListEventsCommand");
const DevOpsGuru_1 = require("../DevOpsGuru");
const DevOpsGuruClient_1 = require("../DevOpsGuruClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListEventsCommand_1.ListEventsCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.listEvents(input, ...args);
};
async function* paginateListEvents(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxResults"] = config.pageSize;
        if (config.client instanceof DevOpsGuru_1.DevOpsGuru) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof DevOpsGuruClient_1.DevOpsGuruClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected DevOpsGuru | DevOpsGuruClient");
        }
        yield page;
        token = page.NextToken;
        hasNext = !!token;
    }
    return undefined;
}
exports.paginateListEvents = paginateListEvents;
