"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateSearchInsights = void 0;
const SearchInsightsCommand_1 = require("../commands/SearchInsightsCommand");
const DevOpsGuru_1 = require("../DevOpsGuru");
const DevOpsGuruClient_1 = require("../DevOpsGuruClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new SearchInsightsCommand_1.SearchInsightsCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.searchInsights(input, ...args);
};
async function* paginateSearchInsights(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxResults"] = config.pageSize;
        if (config.client instanceof DevOpsGuru_1.DevOpsGuru) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof DevOpsGuruClient_1.DevOpsGuruClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected DevOpsGuru | DevOpsGuruClient");
        }
        yield page;
        token = page.NextToken;
        hasNext = !!token;
    }
    return undefined;
}
exports.paginateSearchInsights = paginateSearchInsights;
