import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { DevOpsGuruClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DevOpsGuruClient";
import { DeleteInsightRequest, DeleteInsightResponse } from "../models/models_0";
export interface DeleteInsightCommandInput extends DeleteInsightRequest {
}
export interface DeleteInsightCommandOutput extends DeleteInsightResponse, __MetadataBearer {
}
/**
 * <p>Deletes the insight along with the associated anomalies, events and recommendations.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DevOpsGuruClient, DeleteInsightCommand } from "@aws-sdk/client-devops-guru"; // ES Modules import
 * // const { DevOpsGuruClient, DeleteInsightCommand } = require("@aws-sdk/client-devops-guru"); // CommonJS import
 * const client = new DevOpsGuruClient(config);
 * const command = new DeleteInsightCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DeleteInsightCommandInput} for command's `input` shape.
 * @see {@link DeleteInsightCommandOutput} for command's `response` shape.
 * @see {@link DevOpsGuruClientResolvedConfig | config} for DevOpsGuruClient's `config` shape.
 *
 */
export declare class DeleteInsightCommand extends $Command<DeleteInsightCommandInput, DeleteInsightCommandOutput, DevOpsGuruClientResolvedConfig> {
    readonly input: DeleteInsightCommandInput;
    constructor(input: DeleteInsightCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: DevOpsGuruClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DeleteInsightCommandInput, DeleteInsightCommandOutput>;
    private serialize;
    private deserialize;
}
