import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { DevOpsGuruClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DevOpsGuruClient";
import { DescribeEventSourcesConfigRequest, DescribeEventSourcesConfigResponse } from "../models/models_0";
export interface DescribeEventSourcesConfigCommandInput extends DescribeEventSourcesConfigRequest {
}
export interface DescribeEventSourcesConfigCommandOutput extends DescribeEventSourcesConfigResponse, __MetadataBearer {
}
/**
 * <p>Returns the integration status of services that are integrated with DevOps Guru as Consumer
 * 			via EventBridge. The one service that can be integrated with DevOps Guru is Amazon CodeGuru
 * 			Profiler, which can produce proactive recommendations which can be stored and viewed in
 * 			DevOps Guru.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DevOpsGuruClient, DescribeEventSourcesConfigCommand } from "@aws-sdk/client-devops-guru"; // ES Modules import
 * // const { DevOpsGuruClient, DescribeEventSourcesConfigCommand } = require("@aws-sdk/client-devops-guru"); // CommonJS import
 * const client = new DevOpsGuruClient(config);
 * const command = new DescribeEventSourcesConfigCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DescribeEventSourcesConfigCommandInput} for command's `input` shape.
 * @see {@link DescribeEventSourcesConfigCommandOutput} for command's `response` shape.
 * @see {@link DevOpsGuruClientResolvedConfig | config} for DevOpsGuruClient's `config` shape.
 *
 */
export declare class DescribeEventSourcesConfigCommand extends $Command<DescribeEventSourcesConfigCommandInput, DescribeEventSourcesConfigCommandOutput, DevOpsGuruClientResolvedConfig> {
    readonly input: DescribeEventSourcesConfigCommandInput;
    constructor(input: DescribeEventSourcesConfigCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: DevOpsGuruClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DescribeEventSourcesConfigCommandInput, DescribeEventSourcesConfigCommandOutput>;
    private serialize;
    private deserialize;
}
