import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { DevOpsGuruClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DevOpsGuruClient";
import { DescribeOrganizationOverviewRequest, DescribeOrganizationOverviewResponse } from "../models/models_0";
export interface DescribeOrganizationOverviewCommandInput extends DescribeOrganizationOverviewRequest {
}
export interface DescribeOrganizationOverviewCommandOutput extends DescribeOrganizationOverviewResponse, __MetadataBearer {
}
/**
 * <p>Returns an overview of your organization's history based on the specified time range.
 * 			The overview includes the total reactive and proactive insights.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DevOpsGuruClient, DescribeOrganizationOverviewCommand } from "@aws-sdk/client-devops-guru"; // ES Modules import
 * // const { DevOpsGuruClient, DescribeOrganizationOverviewCommand } = require("@aws-sdk/client-devops-guru"); // CommonJS import
 * const client = new DevOpsGuruClient(config);
 * const command = new DescribeOrganizationOverviewCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DescribeOrganizationOverviewCommandInput} for command's `input` shape.
 * @see {@link DescribeOrganizationOverviewCommandOutput} for command's `response` shape.
 * @see {@link DevOpsGuruClientResolvedConfig | config} for DevOpsGuruClient's `config` shape.
 *
 */
export declare class DescribeOrganizationOverviewCommand extends $Command<DescribeOrganizationOverviewCommandInput, DescribeOrganizationOverviewCommandOutput, DevOpsGuruClientResolvedConfig> {
    readonly input: DescribeOrganizationOverviewCommandInput;
    constructor(input: DescribeOrganizationOverviewCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: DevOpsGuruClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DescribeOrganizationOverviewCommandInput, DescribeOrganizationOverviewCommandOutput>;
    private serialize;
    private deserialize;
}
