import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { DevOpsGuruClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DevOpsGuruClient";
import { ListEventsRequest, ListEventsResponse } from "../models/models_0";
export interface ListEventsCommandInput extends ListEventsRequest {
}
export interface ListEventsCommandOutput extends ListEventsResponse, __MetadataBearer {
}
/**
 * <p> Returns a list of the events emitted by the resources that are evaluated by DevOps Guru.
 * 			You can use filters to specify which events are returned. </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DevOpsGuruClient, ListEventsCommand } from "@aws-sdk/client-devops-guru"; // ES Modules import
 * // const { DevOpsGuruClient, ListEventsCommand } = require("@aws-sdk/client-devops-guru"); // CommonJS import
 * const client = new DevOpsGuruClient(config);
 * const command = new ListEventsCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link ListEventsCommandInput} for command's `input` shape.
 * @see {@link ListEventsCommandOutput} for command's `response` shape.
 * @see {@link DevOpsGuruClientResolvedConfig | config} for DevOpsGuruClient's `config` shape.
 *
 */
export declare class ListEventsCommand extends $Command<ListEventsCommandInput, ListEventsCommandOutput, DevOpsGuruClientResolvedConfig> {
    readonly input: ListEventsCommandInput;
    constructor(input: ListEventsCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: DevOpsGuruClientResolvedConfig, options?: __HttpHandlerOptions): Handler<ListEventsCommandInput, ListEventsCommandOutput>;
    private serialize;
    private deserialize;
}
