import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { DevOpsGuruClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DevOpsGuruClient";
import { ListOrganizationInsightsRequest, ListOrganizationInsightsResponse } from "../models/models_0";
export interface ListOrganizationInsightsCommandInput extends ListOrganizationInsightsRequest {
}
export interface ListOrganizationInsightsCommandOutput extends ListOrganizationInsightsResponse, __MetadataBearer {
}
/**
 * <p>Returns a list of insights associated with the account or OU Id.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DevOpsGuruClient, ListOrganizationInsightsCommand } from "@aws-sdk/client-devops-guru"; // ES Modules import
 * // const { DevOpsGuruClient, ListOrganizationInsightsCommand } = require("@aws-sdk/client-devops-guru"); // CommonJS import
 * const client = new DevOpsGuruClient(config);
 * const command = new ListOrganizationInsightsCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link ListOrganizationInsightsCommandInput} for command's `input` shape.
 * @see {@link ListOrganizationInsightsCommandOutput} for command's `response` shape.
 * @see {@link DevOpsGuruClientResolvedConfig | config} for DevOpsGuruClient's `config` shape.
 *
 */
export declare class ListOrganizationInsightsCommand extends $Command<ListOrganizationInsightsCommandInput, ListOrganizationInsightsCommandOutput, DevOpsGuruClientResolvedConfig> {
    readonly input: ListOrganizationInsightsCommandInput;
    constructor(input: ListOrganizationInsightsCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: DevOpsGuruClientResolvedConfig, options?: __HttpHandlerOptions): Handler<ListOrganizationInsightsCommandInput, ListOrganizationInsightsCommandOutput>;
    private serialize;
    private deserialize;
}
