import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { DevOpsGuruClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DevOpsGuruClient";
import { SearchOrganizationInsightsRequest, SearchOrganizationInsightsResponse } from "../models/models_0";
export interface SearchOrganizationInsightsCommandInput extends SearchOrganizationInsightsRequest {
}
export interface SearchOrganizationInsightsCommandOutput extends SearchOrganizationInsightsResponse, __MetadataBearer {
}
/**
 * <p> Returns a list of insights in your organization. You can specify which insights are
 * 			returned by their start time, one or more statuses (<code>ONGOING</code>,
 * 				<code>CLOSED</code>, and <code>CLOSED</code>), one or more severities
 * 				(<code>LOW</code>, <code>MEDIUM</code>, and <code>HIGH</code>), and type
 * 				(<code>REACTIVE</code> or <code>PROACTIVE</code>). </p>
 * 		       <p> Use the <code>Filters</code> parameter to specify status and severity search
 * 			parameters. Use the <code>Type</code> parameter to specify <code>REACTIVE</code> or
 * 				<code>PROACTIVE</code> in your search. </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DevOpsGuruClient, SearchOrganizationInsightsCommand } from "@aws-sdk/client-devops-guru"; // ES Modules import
 * // const { DevOpsGuruClient, SearchOrganizationInsightsCommand } = require("@aws-sdk/client-devops-guru"); // CommonJS import
 * const client = new DevOpsGuruClient(config);
 * const command = new SearchOrganizationInsightsCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link SearchOrganizationInsightsCommandInput} for command's `input` shape.
 * @see {@link SearchOrganizationInsightsCommandOutput} for command's `response` shape.
 * @see {@link DevOpsGuruClientResolvedConfig | config} for DevOpsGuruClient's `config` shape.
 *
 */
export declare class SearchOrganizationInsightsCommand extends $Command<SearchOrganizationInsightsCommandInput, SearchOrganizationInsightsCommandOutput, DevOpsGuruClientResolvedConfig> {
    readonly input: SearchOrganizationInsightsCommandInput;
    constructor(input: SearchOrganizationInsightsCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: DevOpsGuruClientResolvedConfig, options?: __HttpHandlerOptions): Handler<SearchOrganizationInsightsCommandInput, SearchOrganizationInsightsCommandOutput>;
    private serialize;
    private deserialize;
}
