import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { DevOpsGuruServiceException as __BaseException } from "./DevOpsGuruServiceException";

export declare class AccessDeniedException extends __BaseException {
    readonly name: "AccessDeniedException";
    readonly $fault: "client";
    Message: string | undefined;
    
    constructor(opts: __ExceptionOptionType<AccessDeniedException, __BaseException>);
}

export interface AccountInsightHealth {
    
    OpenProactiveInsights?: number;
    
    OpenReactiveInsights?: number;
}
export declare namespace AccountInsightHealth {
    
    const filterSensitiveLog: (obj: AccountInsightHealth) => any;
}

export interface AccountHealth {
    
    AccountId?: string;
    
    Insight?: AccountInsightHealth;
}
export declare namespace AccountHealth {
    
    const filterSensitiveLog: (obj: AccountHealth) => any;
}

export interface SnsChannelConfig {
    
    TopicArn?: string;
}
export declare namespace SnsChannelConfig {
    
    const filterSensitiveLog: (obj: SnsChannelConfig) => any;
}

export interface NotificationChannelConfig {
    
    Sns: SnsChannelConfig | undefined;
}
export declare namespace NotificationChannelConfig {
    
    const filterSensitiveLog: (obj: NotificationChannelConfig) => any;
}
export interface AddNotificationChannelRequest {
    
    Config: NotificationChannelConfig | undefined;
}
export declare namespace AddNotificationChannelRequest {
    
    const filterSensitiveLog: (obj: AddNotificationChannelRequest) => any;
}
export interface AddNotificationChannelResponse {
    
    Id: string | undefined;
}
export declare namespace AddNotificationChannelResponse {
    
    const filterSensitiveLog: (obj: AddNotificationChannelResponse) => any;
}

export declare class ConflictException extends __BaseException {
    readonly name: "ConflictException";
    readonly $fault: "client";
    Message: string | undefined;
    
    ResourceId: string | undefined;
    
    ResourceType: string | undefined;
    
    constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}

export declare class InternalServerException extends __BaseException {
    readonly name: "InternalServerException";
    readonly $fault: "server";
    Message: string | undefined;
    
    RetryAfterSeconds?: number;
    
    constructor(opts: __ExceptionOptionType<InternalServerException, __BaseException>);
}

export declare class ResourceNotFoundException extends __BaseException {
    readonly name: "ResourceNotFoundException";
    readonly $fault: "client";
    Message: string | undefined;
    
    ResourceId: string | undefined;
    
    ResourceType: string | undefined;
    
    constructor(opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>);
}

export declare class ServiceQuotaExceededException extends __BaseException {
    readonly name: "ServiceQuotaExceededException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>);
}

export declare class ThrottlingException extends __BaseException {
    readonly name: "ThrottlingException";
    readonly $fault: "client";
    Message: string | undefined;
    
    QuotaCode?: string;
    
    ServiceCode?: string;
    
    RetryAfterSeconds?: number;
    
    constructor(opts: __ExceptionOptionType<ThrottlingException, __BaseException>);
}

export interface ValidationExceptionField {
    
    Name: string | undefined;
    
    Message: string | undefined;
}
export declare namespace ValidationExceptionField {
    
    const filterSensitiveLog: (obj: ValidationExceptionField) => any;
}
export declare enum ValidationExceptionReason {
    CANNOT_PARSE = "CANNOT_PARSE",
    FIELD_VALIDATION_FAILED = "FIELD_VALIDATION_FAILED",
    INVALID_PARAMETER_COMBINATION = "INVALID_PARAMETER_COMBINATION",
    OTHER = "OTHER",
    PARAMETER_INCONSISTENT_WITH_SERVICE_STATE = "PARAMETER_INCONSISTENT_WITH_SERVICE_STATE",
    UNKNOWN_OPERATION = "UNKNOWN_OPERATION"
}

export declare class ValidationException extends __BaseException {
    readonly name: "ValidationException";
    readonly $fault: "client";
    
    Message: string | undefined;
    
    Reason?: ValidationExceptionReason | string;
    
    Fields?: ValidationExceptionField[];
    
    constructor(opts: __ExceptionOptionType<ValidationException, __BaseException>);
}
export declare enum EventSourceOptInStatus {
    DISABLED = "DISABLED",
    ENABLED = "ENABLED"
}

export interface AmazonCodeGuruProfilerIntegration {
    
    Status?: EventSourceOptInStatus | string;
}
export declare namespace AmazonCodeGuruProfilerIntegration {
    
    const filterSensitiveLog: (obj: AmazonCodeGuruProfilerIntegration) => any;
}

export interface AnomalyReportedTimeRange {
    
    OpenTime: Date | undefined;
    
    CloseTime?: Date;
}
export declare namespace AnomalyReportedTimeRange {
    
    const filterSensitiveLog: (obj: AnomalyReportedTimeRange) => any;
}

export interface AnomalyResource {
    
    Name?: string;
    
    Type?: string;
}
export declare namespace AnomalyResource {
    
    const filterSensitiveLog: (obj: AnomalyResource) => any;
}
export declare enum AnomalySeverity {
    HIGH = "HIGH",
    LOW = "LOW",
    MEDIUM = "MEDIUM"
}

export interface CloudWatchMetricsDimension {
    
    Name?: string;
    
    Value?: string;
}
export declare namespace CloudWatchMetricsDimension {
    
    const filterSensitiveLog: (obj: CloudWatchMetricsDimension) => any;
}
export declare enum CloudWatchMetricDataStatusCode {
    COMPLETE = "Complete",
    INTERNAL_ERROR = "InternalError",
    PARTIAL_DATA = "PartialData"
}

export interface TimestampMetricValuePair {
    
    Timestamp?: Date;
    
    MetricValue?: number;
}
export declare namespace TimestampMetricValuePair {
    
    const filterSensitiveLog: (obj: TimestampMetricValuePair) => any;
}

export interface CloudWatchMetricsDataSummary {
    
    TimestampMetricValuePairList?: TimestampMetricValuePair[];
    
    StatusCode?: CloudWatchMetricDataStatusCode | string;
}
export declare namespace CloudWatchMetricsDataSummary {
    
    const filterSensitiveLog: (obj: CloudWatchMetricsDataSummary) => any;
}
export declare enum CloudWatchMetricsStat {
    AVERAGE = "Average",
    MAXIMUM = "Maximum",
    MINIMUM = "Minimum",
    P50 = "p50",
    P90 = "p90",
    P99 = "p99",
    SAMPLE_COUNT = "SampleCount",
    SUM = "Sum"
}

export interface CloudWatchMetricsDetail {
    
    MetricName?: string;
    
    Namespace?: string;
    
    Dimensions?: CloudWatchMetricsDimension[];
    
    Stat?: CloudWatchMetricsStat | string;
    
    Unit?: string;
    
    Period?: number;
    
    MetricDataSummary?: CloudWatchMetricsDataSummary;
}
export declare namespace CloudWatchMetricsDetail {
    
    const filterSensitiveLog: (obj: CloudWatchMetricsDetail) => any;
}

export interface PerformanceInsightsMetricDimensionGroup {
    
    Group?: string;
    
    Dimensions?: string[];
    
    Limit?: number;
}
export declare namespace PerformanceInsightsMetricDimensionGroup {
    
    const filterSensitiveLog: (obj: PerformanceInsightsMetricDimensionGroup) => any;
}

export interface PerformanceInsightsMetricQuery {
    
    Metric?: string;
    
    GroupBy?: PerformanceInsightsMetricDimensionGroup;
    
    Filter?: {
        [key: string]: string;
    };
}
export declare namespace PerformanceInsightsMetricQuery {
    
    const filterSensitiveLog: (obj: PerformanceInsightsMetricQuery) => any;
}

export interface PerformanceInsightsReferenceMetric {
    
    MetricQuery?: PerformanceInsightsMetricQuery;
}
export declare namespace PerformanceInsightsReferenceMetric {
    
    const filterSensitiveLog: (obj: PerformanceInsightsReferenceMetric) => any;
}

export interface PerformanceInsightsReferenceScalar {
    
    Value?: number;
}
export declare namespace PerformanceInsightsReferenceScalar {
    
    const filterSensitiveLog: (obj: PerformanceInsightsReferenceScalar) => any;
}

export interface PerformanceInsightsReferenceComparisonValues {
    
    ReferenceScalar?: PerformanceInsightsReferenceScalar;
    
    ReferenceMetric?: PerformanceInsightsReferenceMetric;
}
export declare namespace PerformanceInsightsReferenceComparisonValues {
    
    const filterSensitiveLog: (obj: PerformanceInsightsReferenceComparisonValues) => any;
}

export interface PerformanceInsightsReferenceData {
    
    Name?: string;
    
    ComparisonValues?: PerformanceInsightsReferenceComparisonValues;
}
export declare namespace PerformanceInsightsReferenceData {
    
    const filterSensitiveLog: (obj: PerformanceInsightsReferenceData) => any;
}

export interface PerformanceInsightsStat {
    
    Type?: string;
    
    Value?: number;
}
export declare namespace PerformanceInsightsStat {
    
    const filterSensitiveLog: (obj: PerformanceInsightsStat) => any;
}

export interface PerformanceInsightsMetricsDetail {
    
    MetricDisplayName?: string;
    
    Unit?: string;
    
    MetricQuery?: PerformanceInsightsMetricQuery;
    
    ReferenceData?: PerformanceInsightsReferenceData[];
    
    StatsAtAnomaly?: PerformanceInsightsStat[];
    
    StatsAtBaseline?: PerformanceInsightsStat[];
}
export declare namespace PerformanceInsightsMetricsDetail {
    
    const filterSensitiveLog: (obj: PerformanceInsightsMetricsDetail) => any;
}

export interface AnomalySourceDetails {
    
    CloudWatchMetrics?: CloudWatchMetricsDetail[];
    
    PerformanceInsightsMetrics?: PerformanceInsightsMetricsDetail[];
}
export declare namespace AnomalySourceDetails {
    
    const filterSensitiveLog: (obj: AnomalySourceDetails) => any;
}

export interface AnomalySourceMetadata {
    
    Source?: string;
    
    SourceResourceName?: string;
    
    SourceResourceType?: string;
}
export declare namespace AnomalySourceMetadata {
    
    const filterSensitiveLog: (obj: AnomalySourceMetadata) => any;
}
export declare enum AnomalyStatus {
    CLOSED = "CLOSED",
    ONGOING = "ONGOING"
}

export interface AnomalyTimeRange {
    
    StartTime: Date | undefined;
    
    EndTime?: Date;
}
export declare namespace AnomalyTimeRange {
    
    const filterSensitiveLog: (obj: AnomalyTimeRange) => any;
}
export declare enum AnomalyType {
    CAUSAL = "CAUSAL",
    CONTEXTUAL = "CONTEXTUAL"
}
export interface DeleteInsightRequest {
    
    Id: string | undefined;
}
export declare namespace DeleteInsightRequest {
    
    const filterSensitiveLog: (obj: DeleteInsightRequest) => any;
}
export interface DeleteInsightResponse {
}
export declare namespace DeleteInsightResponse {
    
    const filterSensitiveLog: (obj: DeleteInsightResponse) => any;
}
export interface DescribeAccountHealthRequest {
}
export declare namespace DescribeAccountHealthRequest {
    
    const filterSensitiveLog: (obj: DescribeAccountHealthRequest) => any;
}
export interface DescribeAccountHealthResponse {
    
    OpenReactiveInsights: number | undefined;
    
    OpenProactiveInsights: number | undefined;
    
    MetricsAnalyzed: number | undefined;
    
    ResourceHours: number | undefined;
}
export declare namespace DescribeAccountHealthResponse {
    
    const filterSensitiveLog: (obj: DescribeAccountHealthResponse) => any;
}
export interface DescribeAccountOverviewRequest {
    
    FromTime: Date | undefined;
    
    ToTime?: Date;
}
export declare namespace DescribeAccountOverviewRequest {
    
    const filterSensitiveLog: (obj: DescribeAccountOverviewRequest) => any;
}
export interface DescribeAccountOverviewResponse {
    
    ReactiveInsights: number | undefined;
    
    ProactiveInsights: number | undefined;
    
    MeanTimeToRecoverInMilliseconds: number | undefined;
}
export declare namespace DescribeAccountOverviewResponse {
    
    const filterSensitiveLog: (obj: DescribeAccountOverviewResponse) => any;
}
export interface DescribeAnomalyRequest {
    
    Id: string | undefined;
    
    AccountId?: string;
}
export declare namespace DescribeAnomalyRequest {
    
    const filterSensitiveLog: (obj: DescribeAnomalyRequest) => any;
}

export interface PredictionTimeRange {
    
    StartTime: Date | undefined;
    
    EndTime?: Date;
}
export declare namespace PredictionTimeRange {
    
    const filterSensitiveLog: (obj: PredictionTimeRange) => any;
}

export interface CloudFormationCollection {
    
    StackNames?: string[];
}
export declare namespace CloudFormationCollection {
    
    const filterSensitiveLog: (obj: CloudFormationCollection) => any;
}

export interface TagCollection {
    
    AppBoundaryKey: string | undefined;
    
    TagValues: string[] | undefined;
}
export declare namespace TagCollection {
    
    const filterSensitiveLog: (obj: TagCollection) => any;
}

export interface ResourceCollection {
    
    CloudFormation?: CloudFormationCollection;
    
    Tags?: TagCollection[];
}
export declare namespace ResourceCollection {
    
    const filterSensitiveLog: (obj: ResourceCollection) => any;
}

export interface ProactiveAnomaly {
    
    Id?: string;
    
    Severity?: AnomalySeverity | string;
    
    Status?: AnomalyStatus | string;
    
    UpdateTime?: Date;
    
    AnomalyTimeRange?: AnomalyTimeRange;
    
    AnomalyReportedTimeRange?: AnomalyReportedTimeRange;
    
    PredictionTimeRange?: PredictionTimeRange;
    
    SourceDetails?: AnomalySourceDetails;
    
    AssociatedInsightId?: string;
    
    ResourceCollection?: ResourceCollection;
    
    Limit?: number;
    
    SourceMetadata?: AnomalySourceMetadata;
    
    AnomalyResources?: AnomalyResource[];
}
export declare namespace ProactiveAnomaly {
    
    const filterSensitiveLog: (obj: ProactiveAnomaly) => any;
}

export interface ReactiveAnomaly {
    
    Id?: string;
    
    Severity?: AnomalySeverity | string;
    
    Status?: AnomalyStatus | string;
    
    AnomalyTimeRange?: AnomalyTimeRange;
    
    AnomalyReportedTimeRange?: AnomalyReportedTimeRange;
    
    SourceDetails?: AnomalySourceDetails;
    
    AssociatedInsightId?: string;
    
    ResourceCollection?: ResourceCollection;
    
    Type?: AnomalyType | string;
    
    Name?: string;
    
    Description?: string;
    
    CausalAnomalyId?: string;
    
    AnomalyResources?: AnomalyResource[];
}
export declare namespace ReactiveAnomaly {
    
    const filterSensitiveLog: (obj: ReactiveAnomaly) => any;
}
export interface DescribeAnomalyResponse {
    
    ProactiveAnomaly?: ProactiveAnomaly;
    
    ReactiveAnomaly?: ReactiveAnomaly;
}
export declare namespace DescribeAnomalyResponse {
    
    const filterSensitiveLog: (obj: DescribeAnomalyResponse) => any;
}
export interface DescribeEventSourcesConfigRequest {
}
export declare namespace DescribeEventSourcesConfigRequest {
    
    const filterSensitiveLog: (obj: DescribeEventSourcesConfigRequest) => any;
}

export interface EventSourcesConfig {
    
    AmazonCodeGuruProfiler?: AmazonCodeGuruProfilerIntegration;
}
export declare namespace EventSourcesConfig {
    
    const filterSensitiveLog: (obj: EventSourcesConfig) => any;
}
export interface DescribeEventSourcesConfigResponse {
    
    EventSources?: EventSourcesConfig;
}
export declare namespace DescribeEventSourcesConfigResponse {
    
    const filterSensitiveLog: (obj: DescribeEventSourcesConfigResponse) => any;
}
export interface DescribeFeedbackRequest {
    
    InsightId?: string;
}
export declare namespace DescribeFeedbackRequest {
    
    const filterSensitiveLog: (obj: DescribeFeedbackRequest) => any;
}
export declare enum InsightFeedbackOption {
    ALERT_TOO_SENSITIVE = "ALERT_TOO_SENSITIVE",
    DATA_INCORRECT = "DATA_INCORRECT",
    DATA_NOISY_ANOMALY = "DATA_NOISY_ANOMALY",
    RECOMMENDATION_USEFUL = "RECOMMENDATION_USEFUL",
    VALID_COLLECTION = "VALID_COLLECTION"
}

export interface InsightFeedback {
    
    Id?: string;
    
    Feedback?: InsightFeedbackOption | string;
}
export declare namespace InsightFeedback {
    
    const filterSensitiveLog: (obj: InsightFeedback) => any;
}
export interface DescribeFeedbackResponse {
    
    InsightFeedback?: InsightFeedback;
}
export declare namespace DescribeFeedbackResponse {
    
    const filterSensitiveLog: (obj: DescribeFeedbackResponse) => any;
}
export interface DescribeInsightRequest {
    
    Id: string | undefined;
    
    AccountId?: string;
}
export declare namespace DescribeInsightRequest {
    
    const filterSensitiveLog: (obj: DescribeInsightRequest) => any;
}

export interface InsightTimeRange {
    
    StartTime: Date | undefined;
    
    EndTime?: Date;
}
export declare namespace InsightTimeRange {
    
    const filterSensitiveLog: (obj: InsightTimeRange) => any;
}
export declare enum InsightSeverity {
    HIGH = "HIGH",
    LOW = "LOW",
    MEDIUM = "MEDIUM"
}
export declare enum InsightStatus {
    CLOSED = "CLOSED",
    ONGOING = "ONGOING"
}

export interface ProactiveInsight {
    
    Id?: string;
    
    Name?: string;
    
    Severity?: InsightSeverity | string;
    
    Status?: InsightStatus | string;
    
    InsightTimeRange?: InsightTimeRange;
    
    PredictionTimeRange?: PredictionTimeRange;
    
    ResourceCollection?: ResourceCollection;
    
    SsmOpsItemId?: string;
    
    Description?: string;
}
export declare namespace ProactiveInsight {
    
    const filterSensitiveLog: (obj: ProactiveInsight) => any;
}

export interface ReactiveInsight {
    
    Id?: string;
    
    Name?: string;
    
    Severity?: InsightSeverity | string;
    
    Status?: InsightStatus | string;
    
    InsightTimeRange?: InsightTimeRange;
    
    ResourceCollection?: ResourceCollection;
    
    SsmOpsItemId?: string;
    
    Description?: string;
}
export declare namespace ReactiveInsight {
    
    const filterSensitiveLog: (obj: ReactiveInsight) => any;
}
export interface DescribeInsightResponse {
    
    ProactiveInsight?: ProactiveInsight;
    
    ReactiveInsight?: ReactiveInsight;
}
export declare namespace DescribeInsightResponse {
    
    const filterSensitiveLog: (obj: DescribeInsightResponse) => any;
}
export interface DescribeOrganizationHealthRequest {
    
    AccountIds?: string[];
    
    OrganizationalUnitIds?: string[];
}
export declare namespace DescribeOrganizationHealthRequest {
    
    const filterSensitiveLog: (obj: DescribeOrganizationHealthRequest) => any;
}
export interface DescribeOrganizationHealthResponse {
    
    OpenReactiveInsights: number | undefined;
    
    OpenProactiveInsights: number | undefined;
    
    MetricsAnalyzed: number | undefined;
    
    ResourceHours: number | undefined;
}
export declare namespace DescribeOrganizationHealthResponse {
    
    const filterSensitiveLog: (obj: DescribeOrganizationHealthResponse) => any;
}
export interface DescribeOrganizationOverviewRequest {
    
    FromTime: Date | undefined;
    
    ToTime?: Date;
    
    AccountIds?: string[];
    
    OrganizationalUnitIds?: string[];
}
export declare namespace DescribeOrganizationOverviewRequest {
    
    const filterSensitiveLog: (obj: DescribeOrganizationOverviewRequest) => any;
}
export interface DescribeOrganizationOverviewResponse {
    
    ReactiveInsights: number | undefined;
    
    ProactiveInsights: number | undefined;
}
export declare namespace DescribeOrganizationOverviewResponse {
    
    const filterSensitiveLog: (obj: DescribeOrganizationOverviewResponse) => any;
}
export declare enum OrganizationResourceCollectionType {
    AWS_ACCOUNT = "AWS_ACCOUNT",
    AWS_CLOUD_FORMATION = "AWS_CLOUD_FORMATION",
    AWS_SERVICE = "AWS_SERVICE",
    AWS_TAGS = "AWS_TAGS"
}
export interface DescribeOrganizationResourceCollectionHealthRequest {
    
    OrganizationResourceCollectionType: OrganizationResourceCollectionType | string | undefined;
    
    AccountIds?: string[];
    
    OrganizationalUnitIds?: string[];
    
    NextToken?: string;
    
    MaxResults?: number;
}
export declare namespace DescribeOrganizationResourceCollectionHealthRequest {
    
    const filterSensitiveLog: (obj: DescribeOrganizationResourceCollectionHealthRequest) => any;
}

export interface InsightHealth {
    
    OpenProactiveInsights?: number;
    
    OpenReactiveInsights?: number;
    
    MeanTimeToRecoverInMilliseconds?: number;
}
export declare namespace InsightHealth {
    
    const filterSensitiveLog: (obj: InsightHealth) => any;
}

export interface CloudFormationHealth {
    
    StackName?: string;
    
    Insight?: InsightHealth;
}
export declare namespace CloudFormationHealth {
    
    const filterSensitiveLog: (obj: CloudFormationHealth) => any;
}

export interface ServiceInsightHealth {
    
    OpenProactiveInsights?: number;
    
    OpenReactiveInsights?: number;
}
export declare namespace ServiceInsightHealth {
    
    const filterSensitiveLog: (obj: ServiceInsightHealth) => any;
}
export declare enum ServiceName {
    API_GATEWAY = "API_GATEWAY",
    APPLICATION_ELB = "APPLICATION_ELB",
    AUTO_SCALING_GROUP = "AUTO_SCALING_GROUP",
    CLOUD_FRONT = "CLOUD_FRONT",
    DYNAMO_DB = "DYNAMO_DB",
    EC2 = "EC2",
    ECS = "ECS",
    EKS = "EKS",
    ELASTIC_BEANSTALK = "ELASTIC_BEANSTALK",
    ELASTI_CACHE = "ELASTI_CACHE",
    ELB = "ELB",
    ES = "ES",
    KINESIS = "KINESIS",
    LAMBDA = "LAMBDA",
    NAT_GATEWAY = "NAT_GATEWAY",
    NETWORK_ELB = "NETWORK_ELB",
    RDS = "RDS",
    REDSHIFT = "REDSHIFT",
    ROUTE_53 = "ROUTE_53",
    S3 = "S3",
    SAGE_MAKER = "SAGE_MAKER",
    SNS = "SNS",
    SQS = "SQS",
    STEP_FUNCTIONS = "STEP_FUNCTIONS",
    SWF = "SWF"
}

export interface ServiceHealth {
    
    ServiceName?: ServiceName | string;
    
    Insight?: ServiceInsightHealth;
}
export declare namespace ServiceHealth {
    
    const filterSensitiveLog: (obj: ServiceHealth) => any;
}

export interface TagHealth {
    
    AppBoundaryKey?: string;
    
    TagValue?: string;
    
    Insight?: InsightHealth;
}
export declare namespace TagHealth {
    
    const filterSensitiveLog: (obj: TagHealth) => any;
}
export interface DescribeOrganizationResourceCollectionHealthResponse {
    
    CloudFormation?: CloudFormationHealth[];
    
    Service?: ServiceHealth[];
    
    Account?: AccountHealth[];
    
    NextToken?: string;
    
    Tags?: TagHealth[];
}
export declare namespace DescribeOrganizationResourceCollectionHealthResponse {
    
    const filterSensitiveLog: (obj: DescribeOrganizationResourceCollectionHealthResponse) => any;
}
export declare enum ResourceCollectionType {
    AWS_CLOUD_FORMATION = "AWS_CLOUD_FORMATION",
    AWS_SERVICE = "AWS_SERVICE",
    AWS_TAGS = "AWS_TAGS"
}
export interface DescribeResourceCollectionHealthRequest {
    
    ResourceCollectionType: ResourceCollectionType | string | undefined;
    
    NextToken?: string;
}
export declare namespace DescribeResourceCollectionHealthRequest {
    
    const filterSensitiveLog: (obj: DescribeResourceCollectionHealthRequest) => any;
}
export interface DescribeResourceCollectionHealthResponse {
    
    CloudFormation?: CloudFormationHealth[];
    
    Service?: ServiceHealth[];
    
    NextToken?: string;
    
    Tags?: TagHealth[];
}
export declare namespace DescribeResourceCollectionHealthResponse {
    
    const filterSensitiveLog: (obj: DescribeResourceCollectionHealthResponse) => any;
}
export interface DescribeServiceIntegrationRequest {
}
export declare namespace DescribeServiceIntegrationRequest {
    
    const filterSensitiveLog: (obj: DescribeServiceIntegrationRequest) => any;
}
export declare enum OptInStatus {
    DISABLED = "DISABLED",
    ENABLED = "ENABLED"
}

export interface OpsCenterIntegration {
    
    OptInStatus?: OptInStatus | string;
}
export declare namespace OpsCenterIntegration {
    
    const filterSensitiveLog: (obj: OpsCenterIntegration) => any;
}

export interface ServiceIntegrationConfig {
    
    OpsCenter?: OpsCenterIntegration;
}
export declare namespace ServiceIntegrationConfig {
    
    const filterSensitiveLog: (obj: ServiceIntegrationConfig) => any;
}
export interface DescribeServiceIntegrationResponse {
    
    ServiceIntegration?: ServiceIntegrationConfig;
}
export declare namespace DescribeServiceIntegrationResponse {
    
    const filterSensitiveLog: (obj: DescribeServiceIntegrationResponse) => any;
}
export interface GetCostEstimationRequest {
    
    NextToken?: string;
}
export declare namespace GetCostEstimationRequest {
    
    const filterSensitiveLog: (obj: GetCostEstimationRequest) => any;
}
export declare enum CostEstimationServiceResourceState {
    ACTIVE = "ACTIVE",
    INACTIVE = "INACTIVE"
}

export interface ServiceResourceCost {
    
    Type?: string;
    
    State?: CostEstimationServiceResourceState | string;
    
    Count?: number;
    
    UnitCost?: number;
    
    Cost?: number;
}
export declare namespace ServiceResourceCost {
    
    const filterSensitiveLog: (obj: ServiceResourceCost) => any;
}

export interface CloudFormationCostEstimationResourceCollectionFilter {
    
    StackNames?: string[];
}
export declare namespace CloudFormationCostEstimationResourceCollectionFilter {
    
    const filterSensitiveLog: (obj: CloudFormationCostEstimationResourceCollectionFilter) => any;
}

export interface TagCostEstimationResourceCollectionFilter {
    
    AppBoundaryKey: string | undefined;
    
    TagValues: string[] | undefined;
}
export declare namespace TagCostEstimationResourceCollectionFilter {
    
    const filterSensitiveLog: (obj: TagCostEstimationResourceCollectionFilter) => any;
}

export interface CostEstimationResourceCollectionFilter {
    
    CloudFormation?: CloudFormationCostEstimationResourceCollectionFilter;
    
    Tags?: TagCostEstimationResourceCollectionFilter[];
}
export declare namespace CostEstimationResourceCollectionFilter {
    
    const filterSensitiveLog: (obj: CostEstimationResourceCollectionFilter) => any;
}
export declare enum CostEstimationStatus {
    COMPLETED = "COMPLETED",
    ONGOING = "ONGOING"
}

export interface CostEstimationTimeRange {
    
    StartTime?: Date;
    
    EndTime?: Date;
}
export declare namespace CostEstimationTimeRange {
    
    const filterSensitiveLog: (obj: CostEstimationTimeRange) => any;
}
export interface GetCostEstimationResponse {
    
    ResourceCollection?: CostEstimationResourceCollectionFilter;
    
    Status?: CostEstimationStatus | string;
    
    Costs?: ServiceResourceCost[];
    
    TimeRange?: CostEstimationTimeRange;
    
    TotalCost?: number;
    
    NextToken?: string;
}
export declare namespace GetCostEstimationResponse {
    
    const filterSensitiveLog: (obj: GetCostEstimationResponse) => any;
}
export interface GetResourceCollectionRequest {
    
    ResourceCollectionType: ResourceCollectionType | string | undefined;
    
    NextToken?: string;
}
export declare namespace GetResourceCollectionRequest {
    
    const filterSensitiveLog: (obj: GetResourceCollectionRequest) => any;
}

export interface CloudFormationCollectionFilter {
    
    StackNames?: string[];
}
export declare namespace CloudFormationCollectionFilter {
    
    const filterSensitiveLog: (obj: CloudFormationCollectionFilter) => any;
}

export interface TagCollectionFilter {
    
    AppBoundaryKey: string | undefined;
    
    TagValues: string[] | undefined;
}
export declare namespace TagCollectionFilter {
    
    const filterSensitiveLog: (obj: TagCollectionFilter) => any;
}

export interface ResourceCollectionFilter {
    
    CloudFormation?: CloudFormationCollectionFilter;
    
    Tags?: TagCollectionFilter[];
}
export declare namespace ResourceCollectionFilter {
    
    const filterSensitiveLog: (obj: ResourceCollectionFilter) => any;
}
export interface GetResourceCollectionResponse {
    
    ResourceCollection?: ResourceCollectionFilter;
    
    NextToken?: string;
}
export declare namespace GetResourceCollectionResponse {
    
    const filterSensitiveLog: (obj: GetResourceCollectionResponse) => any;
}

export interface StartTimeRange {
    
    FromTime?: Date;
    
    ToTime?: Date;
}
export declare namespace StartTimeRange {
    
    const filterSensitiveLog: (obj: StartTimeRange) => any;
}
export interface ListAnomaliesForInsightRequest {
    
    InsightId: string | undefined;
    
    StartTimeRange?: StartTimeRange;
    
    MaxResults?: number;
    
    NextToken?: string;
    
    AccountId?: string;
}
export declare namespace ListAnomaliesForInsightRequest {
    
    const filterSensitiveLog: (obj: ListAnomaliesForInsightRequest) => any;
}

export interface ProactiveAnomalySummary {
    
    Id?: string;
    
    Severity?: AnomalySeverity | string;
    
    Status?: AnomalyStatus | string;
    
    UpdateTime?: Date;
    
    AnomalyTimeRange?: AnomalyTimeRange;
    
    AnomalyReportedTimeRange?: AnomalyReportedTimeRange;
    
    PredictionTimeRange?: PredictionTimeRange;
    
    SourceDetails?: AnomalySourceDetails;
    
    AssociatedInsightId?: string;
    
    ResourceCollection?: ResourceCollection;
    
    Limit?: number;
    
    SourceMetadata?: AnomalySourceMetadata;
    
    AnomalyResources?: AnomalyResource[];
}
export declare namespace ProactiveAnomalySummary {
    
    const filterSensitiveLog: (obj: ProactiveAnomalySummary) => any;
}

export interface ReactiveAnomalySummary {
    
    Id?: string;
    
    Severity?: AnomalySeverity | string;
    
    Status?: AnomalyStatus | string;
    
    AnomalyTimeRange?: AnomalyTimeRange;
    
    AnomalyReportedTimeRange?: AnomalyReportedTimeRange;
    
    SourceDetails?: AnomalySourceDetails;
    
    AssociatedInsightId?: string;
    
    ResourceCollection?: ResourceCollection;
    
    Type?: AnomalyType | string;
    
    Name?: string;
    
    Description?: string;
    
    CausalAnomalyId?: string;
    
    AnomalyResources?: AnomalyResource[];
}
export declare namespace ReactiveAnomalySummary {
    
    const filterSensitiveLog: (obj: ReactiveAnomalySummary) => any;
}
export interface ListAnomaliesForInsightResponse {
    
    ProactiveAnomalies?: ProactiveAnomalySummary[];
    
    ReactiveAnomalies?: ReactiveAnomalySummary[];
    
    NextToken?: string;
}
export declare namespace ListAnomaliesForInsightResponse {
    
    const filterSensitiveLog: (obj: ListAnomaliesForInsightResponse) => any;
}
export declare enum EventDataSource {
    AWS_CLOUD_TRAIL = "AWS_CLOUD_TRAIL",
    AWS_CODE_DEPLOY = "AWS_CODE_DEPLOY"
}
export declare enum EventClass {
    CONFIG_CHANGE = "CONFIG_CHANGE",
    DEPLOYMENT = "DEPLOYMENT",
    INFRASTRUCTURE = "INFRASTRUCTURE",
    SCHEMA_CHANGE = "SCHEMA_CHANGE",
    SECURITY_CHANGE = "SECURITY_CHANGE"
}

export interface EventTimeRange {
    
    FromTime: Date | undefined;
    
    ToTime: Date | undefined;
}
export declare namespace EventTimeRange {
    
    const filterSensitiveLog: (obj: EventTimeRange) => any;
}

export interface ListEventsFilters {
    
    InsightId?: string;
    
    EventTimeRange?: EventTimeRange;
    
    EventClass?: EventClass | string;
    
    EventSource?: string;
    
    DataSource?: EventDataSource | string;
    
    ResourceCollection?: ResourceCollection;
}
export declare namespace ListEventsFilters {
    
    const filterSensitiveLog: (obj: ListEventsFilters) => any;
}
export interface ListEventsRequest {
    
    Filters: ListEventsFilters | undefined;
    
    MaxResults?: number;
    
    NextToken?: string;
    
    AccountId?: string;
}
export declare namespace ListEventsRequest {
    
    const filterSensitiveLog: (obj: ListEventsRequest) => any;
}

export interface EventResource {
    
    Type?: string;
    
    Name?: string;
    
    Arn?: string;
}
export declare namespace EventResource {
    
    const filterSensitiveLog: (obj: EventResource) => any;
}

export interface Event {
    
    ResourceCollection?: ResourceCollection;
    
    Id?: string;
    
    Time?: Date;
    
    EventSource?: string;
    
    Name?: string;
    
    DataSource?: EventDataSource | string;
    
    EventClass?: EventClass | string;
    
    Resources?: EventResource[];
}
export declare namespace Event {
    
    const filterSensitiveLog: (obj: Event) => any;
}
export interface ListEventsResponse {
    
    Events: Event[] | undefined;
    
    NextToken?: string;
}
export declare namespace ListEventsResponse {
    
    const filterSensitiveLog: (obj: ListEventsResponse) => any;
}
export declare enum InsightType {
    PROACTIVE = "PROACTIVE",
    REACTIVE = "REACTIVE"
}

export interface ListInsightsAnyStatusFilter {
    
    Type: InsightType | string | undefined;
    
    StartTimeRange: StartTimeRange | undefined;
}
export declare namespace ListInsightsAnyStatusFilter {
    
    const filterSensitiveLog: (obj: ListInsightsAnyStatusFilter) => any;
}

export interface EndTimeRange {
    
    FromTime?: Date;
    
    ToTime?: Date;
}
export declare namespace EndTimeRange {
    
    const filterSensitiveLog: (obj: EndTimeRange) => any;
}

export interface ListInsightsClosedStatusFilter {
    
    Type: InsightType | string | undefined;
    
    EndTimeRange: EndTimeRange | undefined;
}
export declare namespace ListInsightsClosedStatusFilter {
    
    const filterSensitiveLog: (obj: ListInsightsClosedStatusFilter) => any;
}

export interface ListInsightsOngoingStatusFilter {
    
    Type: InsightType | string | undefined;
}
export declare namespace ListInsightsOngoingStatusFilter {
    
    const filterSensitiveLog: (obj: ListInsightsOngoingStatusFilter) => any;
}

export interface ListInsightsStatusFilter {
    
    Ongoing?: ListInsightsOngoingStatusFilter;
    
    Closed?: ListInsightsClosedStatusFilter;
    
    Any?: ListInsightsAnyStatusFilter;
}
export declare namespace ListInsightsStatusFilter {
    
    const filterSensitiveLog: (obj: ListInsightsStatusFilter) => any;
}
export interface ListInsightsRequest {
    
    StatusFilter: ListInsightsStatusFilter | undefined;
    
    MaxResults?: number;
    
    NextToken?: string;
}
export declare namespace ListInsightsRequest {
    
    const filterSensitiveLog: (obj: ListInsightsRequest) => any;
}

export interface ServiceCollection {
    
    ServiceNames?: (ServiceName | string)[];
}
export declare namespace ServiceCollection {
    
    const filterSensitiveLog: (obj: ServiceCollection) => any;
}

export interface ProactiveInsightSummary {
    
    Id?: string;
    
    Name?: string;
    
    Severity?: InsightSeverity | string;
    
    Status?: InsightStatus | string;
    
    InsightTimeRange?: InsightTimeRange;
    
    PredictionTimeRange?: PredictionTimeRange;
    
    ResourceCollection?: ResourceCollection;
    
    ServiceCollection?: ServiceCollection;
    
    AssociatedResourceArns?: string[];
}
export declare namespace ProactiveInsightSummary {
    
    const filterSensitiveLog: (obj: ProactiveInsightSummary) => any;
}

export interface ReactiveInsightSummary {
    
    Id?: string;
    
    Name?: string;
    
    Severity?: InsightSeverity | string;
    
    Status?: InsightStatus | string;
    
    InsightTimeRange?: InsightTimeRange;
    
    ResourceCollection?: ResourceCollection;
    
    ServiceCollection?: ServiceCollection;
    
    AssociatedResourceArns?: string[];
}
export declare namespace ReactiveInsightSummary {
    
    const filterSensitiveLog: (obj: ReactiveInsightSummary) => any;
}
export interface ListInsightsResponse {
    
    ProactiveInsights?: ProactiveInsightSummary[];
    
    ReactiveInsights?: ReactiveInsightSummary[];
    
    NextToken?: string;
}
export declare namespace ListInsightsResponse {
    
    const filterSensitiveLog: (obj: ListInsightsResponse) => any;
}
export interface ListNotificationChannelsRequest {
    
    NextToken?: string;
}
export declare namespace ListNotificationChannelsRequest {
    
    const filterSensitiveLog: (obj: ListNotificationChannelsRequest) => any;
}

export interface NotificationChannel {
    
    Id?: string;
    
    Config?: NotificationChannelConfig;
}
export declare namespace NotificationChannel {
    
    const filterSensitiveLog: (obj: NotificationChannel) => any;
}
export interface ListNotificationChannelsResponse {
    
    Channels?: NotificationChannel[];
    
    NextToken?: string;
}
export declare namespace ListNotificationChannelsResponse {
    
    const filterSensitiveLog: (obj: ListNotificationChannelsResponse) => any;
}
export interface ListOrganizationInsightsRequest {
    
    StatusFilter: ListInsightsStatusFilter | undefined;
    
    MaxResults?: number;
    
    AccountIds?: string[];
    
    OrganizationalUnitIds?: string[];
    
    NextToken?: string;
}
export declare namespace ListOrganizationInsightsRequest {
    
    const filterSensitiveLog: (obj: ListOrganizationInsightsRequest) => any;
}

export interface ProactiveOrganizationInsightSummary {
    
    Id?: string;
    
    AccountId?: string;
    
    OrganizationalUnitId?: string;
    
    Name?: string;
    
    Severity?: InsightSeverity | string;
    
    Status?: InsightStatus | string;
    
    InsightTimeRange?: InsightTimeRange;
    
    PredictionTimeRange?: PredictionTimeRange;
    
    ResourceCollection?: ResourceCollection;
    
    ServiceCollection?: ServiceCollection;
}
export declare namespace ProactiveOrganizationInsightSummary {
    
    const filterSensitiveLog: (obj: ProactiveOrganizationInsightSummary) => any;
}

export interface ReactiveOrganizationInsightSummary {
    
    Id?: string;
    
    AccountId?: string;
    
    OrganizationalUnitId?: string;
    
    Name?: string;
    
    Severity?: InsightSeverity | string;
    
    Status?: InsightStatus | string;
    
    InsightTimeRange?: InsightTimeRange;
    
    ResourceCollection?: ResourceCollection;
    
    ServiceCollection?: ServiceCollection;
}
export declare namespace ReactiveOrganizationInsightSummary {
    
    const filterSensitiveLog: (obj: ReactiveOrganizationInsightSummary) => any;
}
export interface ListOrganizationInsightsResponse {
    
    ProactiveInsights?: ProactiveOrganizationInsightSummary[];
    
    ReactiveInsights?: ReactiveOrganizationInsightSummary[];
    
    NextToken?: string;
}
export declare namespace ListOrganizationInsightsResponse {
    
    const filterSensitiveLog: (obj: ListOrganizationInsightsResponse) => any;
}
export declare enum Locale {
    DE_DE = "DE_DE",
    EN_GB = "EN_GB",
    EN_US = "EN_US",
    ES_ES = "ES_ES",
    FR_FR = "FR_FR",
    IT_IT = "IT_IT",
    JA_JP = "JA_JP",
    KO_KR = "KO_KR",
    PT_BR = "PT_BR",
    ZH_CN = "ZH_CN",
    ZH_TW = "ZH_TW"
}
export interface ListRecommendationsRequest {
    
    InsightId: string | undefined;
    
    NextToken?: string;
    
    Locale?: Locale | string;
    
    AccountId?: string;
}
export declare namespace ListRecommendationsRequest {
    
    const filterSensitiveLog: (obj: ListRecommendationsRequest) => any;
}

export interface RecommendationRelatedAnomalyResource {
    
    Name?: string;
    
    Type?: string;
}
export declare namespace RecommendationRelatedAnomalyResource {
    
    const filterSensitiveLog: (obj: RecommendationRelatedAnomalyResource) => any;
}

export interface RecommendationRelatedCloudWatchMetricsSourceDetail {
    
    MetricName?: string;
    
    Namespace?: string;
}
export declare namespace RecommendationRelatedCloudWatchMetricsSourceDetail {
    
    const filterSensitiveLog: (obj: RecommendationRelatedCloudWatchMetricsSourceDetail) => any;
}

export interface RecommendationRelatedAnomalySourceDetail {
    
    CloudWatchMetrics?: RecommendationRelatedCloudWatchMetricsSourceDetail[];
}
export declare namespace RecommendationRelatedAnomalySourceDetail {
    
    const filterSensitiveLog: (obj: RecommendationRelatedAnomalySourceDetail) => any;
}

export interface RecommendationRelatedAnomaly {
    
    Resources?: RecommendationRelatedAnomalyResource[];
    
    SourceDetails?: RecommendationRelatedAnomalySourceDetail[];
    
    AnomalyId?: string;
}
export declare namespace RecommendationRelatedAnomaly {
    
    const filterSensitiveLog: (obj: RecommendationRelatedAnomaly) => any;
}

export interface RecommendationRelatedEventResource {
    
    Name?: string;
    
    Type?: string;
}
export declare namespace RecommendationRelatedEventResource {
    
    const filterSensitiveLog: (obj: RecommendationRelatedEventResource) => any;
}

export interface RecommendationRelatedEvent {
    
    Name?: string;
    
    Resources?: RecommendationRelatedEventResource[];
}
export declare namespace RecommendationRelatedEvent {
    
    const filterSensitiveLog: (obj: RecommendationRelatedEvent) => any;
}

export interface Recommendation {
    
    Description?: string;
    
    Link?: string;
    
    Name?: string;
    
    Reason?: string;
    
    RelatedEvents?: RecommendationRelatedEvent[];
    
    RelatedAnomalies?: RecommendationRelatedAnomaly[];
    
    Category?: string;
}
export declare namespace Recommendation {
    
    const filterSensitiveLog: (obj: Recommendation) => any;
}
export interface ListRecommendationsResponse {
    
    Recommendations?: Recommendation[];
    
    NextToken?: string;
}
export declare namespace ListRecommendationsResponse {
    
    const filterSensitiveLog: (obj: ListRecommendationsResponse) => any;
}
export interface PutFeedbackRequest {
    
    InsightFeedback?: InsightFeedback;
}
export declare namespace PutFeedbackRequest {
    
    const filterSensitiveLog: (obj: PutFeedbackRequest) => any;
}
export interface PutFeedbackResponse {
}
export declare namespace PutFeedbackResponse {
    
    const filterSensitiveLog: (obj: PutFeedbackResponse) => any;
}
export interface RemoveNotificationChannelRequest {
    
    Id: string | undefined;
}
export declare namespace RemoveNotificationChannelRequest {
    
    const filterSensitiveLog: (obj: RemoveNotificationChannelRequest) => any;
}
export interface RemoveNotificationChannelResponse {
}
export declare namespace RemoveNotificationChannelResponse {
    
    const filterSensitiveLog: (obj: RemoveNotificationChannelResponse) => any;
}

export interface SearchInsightsFilters {
    
    Severities?: (InsightSeverity | string)[];
    
    Statuses?: (InsightStatus | string)[];
    
    ResourceCollection?: ResourceCollection;
    
    ServiceCollection?: ServiceCollection;
}
export declare namespace SearchInsightsFilters {
    
    const filterSensitiveLog: (obj: SearchInsightsFilters) => any;
}
export interface SearchInsightsRequest {
    
    StartTimeRange: StartTimeRange | undefined;
    
    Filters?: SearchInsightsFilters;
    
    MaxResults?: number;
    
    NextToken?: string;
    
    Type: InsightType | string | undefined;
}
export declare namespace SearchInsightsRequest {
    
    const filterSensitiveLog: (obj: SearchInsightsRequest) => any;
}
export interface SearchInsightsResponse {
    
    ProactiveInsights?: ProactiveInsightSummary[];
    
    ReactiveInsights?: ReactiveInsightSummary[];
    
    NextToken?: string;
}
export declare namespace SearchInsightsResponse {
    
    const filterSensitiveLog: (obj: SearchInsightsResponse) => any;
}

export interface SearchOrganizationInsightsFilters {
    
    Severities?: (InsightSeverity | string)[];
    
    Statuses?: (InsightStatus | string)[];
    
    ResourceCollection?: ResourceCollection;
    
    ServiceCollection?: ServiceCollection;
}
export declare namespace SearchOrganizationInsightsFilters {
    
    const filterSensitiveLog: (obj: SearchOrganizationInsightsFilters) => any;
}
export interface SearchOrganizationInsightsRequest {
    
    AccountIds: string[] | undefined;
    
    StartTimeRange: StartTimeRange | undefined;
    
    Filters?: SearchOrganizationInsightsFilters;
    
    MaxResults?: number;
    
    NextToken?: string;
    
    Type: InsightType | string | undefined;
}
export declare namespace SearchOrganizationInsightsRequest {
    
    const filterSensitiveLog: (obj: SearchOrganizationInsightsRequest) => any;
}
export interface SearchOrganizationInsightsResponse {
    
    ProactiveInsights?: ProactiveInsightSummary[];
    
    ReactiveInsights?: ReactiveInsightSummary[];
    
    NextToken?: string;
}
export declare namespace SearchOrganizationInsightsResponse {
    
    const filterSensitiveLog: (obj: SearchOrganizationInsightsResponse) => any;
}
export interface StartCostEstimationRequest {
    
    ResourceCollection: CostEstimationResourceCollectionFilter | undefined;
    
    ClientToken?: string;
}
export declare namespace StartCostEstimationRequest {
    
    const filterSensitiveLog: (obj: StartCostEstimationRequest) => any;
}
export interface StartCostEstimationResponse {
}
export declare namespace StartCostEstimationResponse {
    
    const filterSensitiveLog: (obj: StartCostEstimationResponse) => any;
}
export interface UpdateEventSourcesConfigRequest {
    
    EventSources?: EventSourcesConfig;
}
export declare namespace UpdateEventSourcesConfigRequest {
    
    const filterSensitiveLog: (obj: UpdateEventSourcesConfigRequest) => any;
}
export interface UpdateEventSourcesConfigResponse {
}
export declare namespace UpdateEventSourcesConfigResponse {
    
    const filterSensitiveLog: (obj: UpdateEventSourcesConfigResponse) => any;
}
export declare enum UpdateResourceCollectionAction {
    ADD = "ADD",
    REMOVE = "REMOVE"
}

export interface UpdateCloudFormationCollectionFilter {
    
    StackNames?: string[];
}
export declare namespace UpdateCloudFormationCollectionFilter {
    
    const filterSensitiveLog: (obj: UpdateCloudFormationCollectionFilter) => any;
}

export interface UpdateTagCollectionFilter {
    
    AppBoundaryKey: string | undefined;
    
    TagValues: string[] | undefined;
}
export declare namespace UpdateTagCollectionFilter {
    
    const filterSensitiveLog: (obj: UpdateTagCollectionFilter) => any;
}

export interface UpdateResourceCollectionFilter {
    
    CloudFormation?: UpdateCloudFormationCollectionFilter;
    
    Tags?: UpdateTagCollectionFilter[];
}
export declare namespace UpdateResourceCollectionFilter {
    
    const filterSensitiveLog: (obj: UpdateResourceCollectionFilter) => any;
}
export interface UpdateResourceCollectionRequest {
    
    Action: UpdateResourceCollectionAction | string | undefined;
    
    ResourceCollection: UpdateResourceCollectionFilter | undefined;
}
export declare namespace UpdateResourceCollectionRequest {
    
    const filterSensitiveLog: (obj: UpdateResourceCollectionRequest) => any;
}
export interface UpdateResourceCollectionResponse {
}
export declare namespace UpdateResourceCollectionResponse {
    
    const filterSensitiveLog: (obj: UpdateResourceCollectionResponse) => any;
}

export interface OpsCenterIntegrationConfig {
    
    OptInStatus?: OptInStatus | string;
}
export declare namespace OpsCenterIntegrationConfig {
    
    const filterSensitiveLog: (obj: OpsCenterIntegrationConfig) => any;
}

export interface UpdateServiceIntegrationConfig {
    
    OpsCenter?: OpsCenterIntegrationConfig;
}
export declare namespace UpdateServiceIntegrationConfig {
    
    const filterSensitiveLog: (obj: UpdateServiceIntegrationConfig) => any;
}
export interface UpdateServiceIntegrationRequest {
    
    ServiceIntegration: UpdateServiceIntegrationConfig | undefined;
}
export declare namespace UpdateServiceIntegrationRequest {
    
    const filterSensitiveLog: (obj: UpdateServiceIntegrationRequest) => any;
}
export interface UpdateServiceIntegrationResponse {
}
export declare namespace UpdateServiceIntegrationResponse {
    
    const filterSensitiveLog: (obj: UpdateServiceIntegrationResponse) => any;
}
